@@ -10,7 +10,8 @@ from typer.core import TyperGroup
 
 from ops2deb import __version__, builder, formatter, generator, logger, parser, updater
 from ops2deb.exceptions import Ops2debError
-from ops2deb.fetcher import DEFAULT_CACHE_DIRECTORY, set_cache_directory
+from ops2deb.fetcher import DEFAULT_CACHE_DIRECTORY, Fetcher
+from ops2deb.migrate import migrate_configuration_file
 
 
 class DefaultCommandGroup(TyperGroup):
@@ -74,14 +75,22 @@ option_exit_code: int = typer.Option(
     callback=validate_exit_code,
 )
 
-option_configuration = typer.Option(
-    "ops2deb.yml",
+option_configuration: Path = typer.Option(
+    Path("ops2deb.yml"),
     "--config",
     "-c",
     envvar="OPS2DEB_CONFIG",
     help="Path to configuration file.",
 )
 
+option_lockfile: Path = typer.Option(
+    Path("ops2deb.lock.yml"),
+    "--lock",
+    "-k",
+    envvar="OPS2DEB_LOCKFILE",
+    help="Path to lockfile.",
+)
+
 option_cache_directory: Path = typer.Option(
     DEFAULT_CACHE_DIRECTORY,
     "--cache-dir",
@@ -131,16 +140,18 @@ def default(
     verbose: bool = option_verbose,
     exit_code: int = option_exit_code,
     configuration_path: Path = option_configuration,
+    lockfile_path: Path = option_lockfile,
     output_directory: Path = option_output_directory,
     cache_directory: Path = option_cache_directory,
     debian_repository: Optional[str] = option_debian_repository,
     only: Optional[List[str]] = option_only,
     workers_count: int = option_workers_count,
 ) -> None:
-    set_cache_directory(cache_directory)
     try:
+        fetcher = Fetcher(cache_directory, lockfile_path)
         blueprints = parser.parse(configuration_path)
         packages = generator.generate(
+            fetcher,
             blueprints,
             output_directory,
             configuration_path.parent,
@@ -157,15 +168,17 @@ def generate(
     verbose: bool = option_verbose,
     exit_code: int = option_exit_code,
     configuration_path: Path = option_configuration,
+    lockfile_path: Path = option_lockfile,
     output_directory: Path = option_output_directory,
     cache_directory: Path = option_cache_directory,
     debian_repository: Optional[str] = option_debian_repository,
     only: Optional[List[str]] = option_only,
 ) -> None:
-    set_cache_directory(cache_directory)
     try:
+        fetcher = Fetcher(cache_directory, lockfile_path)
         blueprints = parser.parse(configuration_path)
         generator.generate(
+            fetcher,
             blueprints,
             output_directory,
             configuration_path.parent,
@@ -199,6 +212,7 @@ def update(
     verbose: bool = option_verbose,
     exit_code: int = option_exit_code,
     configuration_path: Path = option_configuration,
+    lockfile_path: Path = option_lockfile,
     cache_directory: Path = option_cache_directory,
     dry_run: bool = typer.Option(
         False, "--dry-run", "-d", help="Don't edit config file."
@@ -217,9 +231,11 @@ def update(
         help="Name of blueprint that should not be updated. Can be used multiple times.",
     ),
 ) -> None:
-    set_cache_directory(cache_directory)
     try:
-        updater.update(configuration_path, dry_run, output_path, skip)
+        fetcher = Fetcher(cache_directory, lockfile_path)
+        updater.update(
+            configuration_path, lockfile_path, fetcher, dry_run, output_path, skip
+        )
     except Ops2debError as e:
         error(e, exit_code)
 
@@ -253,5 +269,33 @@ def version() -> None:
     logger.info(__version__)
 
 
+@app.command(help="Update lockfile.")
+def lock(
+    verbose: bool = option_verbose,
+    exit_code: int = option_exit_code,
+    configuration_path: Path = option_configuration,
+    lockfile_path: Path = option_lockfile,
+    cache_directory: Path = option_cache_directory,
+) -> None:
+    try:
+        fetcher = Fetcher(cache_directory, lockfile_path)
+        fetcher.update_lockfile(configuration_path)
+    except Ops2debError as e:
+        error(e, exit_code)
+
+
+@app.command(help="Move file sha256 hashes to dedicated lockfile")
+def migrate(
+    verbose: bool = option_verbose,
+    exit_code: int = option_exit_code,
+    configuration_path: Path = option_configuration,
+    lockfile_path: Path = option_lockfile,
+) -> None:
+    try:
+        migrate_configuration_file(configuration_path, lockfile_path)
+    except Ops2debError as e:
+        error(e, exit_code)
+
+
 def main() -> None:
     app()
