@@ -8,7 +8,7 @@ from dirsync import sync
 from ops2deb import logger
 from ops2deb.apt import DebianRepositoryPackage, sync_list_repository_packages
 from ops2deb.exceptions import Ops2debGeneratorError, Ops2debGeneratorScriptError
-from ops2deb.fetcher import FetchResult, fetch_remote_files
+from ops2deb.fetcher import Fetcher, FetchResult
 from ops2deb.parser import Blueprint, HereDocument, SourceDestinationStr, extend
 from ops2deb.templates import environment
 from ops2deb.utils import working_directory
@@ -26,14 +26,16 @@ class SourcePackage:
     ):
         epoch = f"{blueprint.epoch}:" if blueprint.epoch else ""
         self.debian_version = f"{epoch}{blueprint.version}-{blueprint.revision}~ops2deb"
-        self.directory_name = f"{blueprint.name}_{blueprint.version}_{blueprint.arch}"
+        self.directory_name = (
+            f"{blueprint.name}_{blueprint.version}_{blueprint.architecture}"
+        )
         self.package_directory = (output_directory / self.directory_name).absolute()
+        self.configuration_directory = configuration_directory.absolute()
         self.debian_directory = self.package_directory / "debian"
         self.source_directory = self.package_directory / "src"
         self.fetch_directory = self.package_directory / "fetched"
         self.blueprint = blueprint
         self.remote_file = self.blueprint.render_fetch()
-        self.configuration_directory = configuration_directory
 
     def _render_template(self, template_name: str) -> None:
         template = environment.get_template(f"{template_name}")
@@ -47,7 +49,7 @@ class SourcePackage:
         shutil.rmtree(self.fetch_directory, ignore_errors=True)
         shutil.rmtree(self.source_directory, ignore_errors=True)
         self.source_directory.mkdir(parents=True)
-        for path in ["usr/bin", "usr/share", "usr/lib"]:
+        for path in ["usr/bin", "usr/share", "usr/lib", "etc"]:
             (self.source_directory / path).mkdir(parents=True)
 
     def _populate_with_fetch_result(self, fetch_result: FetchResult) -> None:
@@ -126,8 +128,8 @@ class SourcePackage:
 
     def generate(self, fetch_results: dict[str, FetchResult]) -> None:
         fetch_result: FetchResult | None = None
-        if self.remote_file is not None:
-            fetch_result = fetch_results.get(self.remote_file.url, None)
+        if (url := self.blueprint.render_fetch_url()) is not None:
+            fetch_result = fetch_results.get(url, None)
             if fetch_result is None:
                 return
 
@@ -152,11 +154,11 @@ class SourcePackage:
         ]:
             self._render_template(template)
 
-        # if blueprint has no fetch instruction, we stay in the directory from which
-        # ops2deb was called, otherwise we run install and script from the fetch directory
-        cwd = self.fetch_directory if self.blueprint.fetch else Path(".")
-
-        with working_directory(cwd):
+        # if blueprint has no fetch instruction, we walk in the directory where ops2deb
+        # config file is, otherwise we run install and script from the fetch directory
+        with working_directory(
+            self.fetch_directory if self.blueprint.fetch else self.configuration_directory
+        ):
             # copy files / create here documents
             self._install_files()
             # run blueprint script
@@ -171,7 +173,9 @@ def filter_already_published_packages(
     for package in packages:
         if (
             DebianRepositoryPackage(
-                package.blueprint.name, package.debian_version, package.blueprint.arch
+                package.blueprint.name,
+                package.debian_version,
+                package.blueprint.architecture,
             )
             not in already_published_packages
         ):
@@ -180,6 +184,7 @@ def filter_already_published_packages(
 
 
 def generate(
+    fetcher: Fetcher,
     blueprints: list[Blueprint],
     output_directory: Path,
     configuration_directory: Path,
@@ -201,7 +206,7 @@ def generate(
 
     # run fetch instructions (download, verify, extract) in parallel
     files = [p.remote_file for p in packages if p.remote_file is not None]
-    fetch_results, fetch_errors = fetch_remote_files(files)
+    fetch_results, fetch_errors = fetcher.fetch_urls_and_check_hashes(files)
 
     for package in packages:
         package.generate(fetch_results)
